function dsp_con

% DSP_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.13 $ $Date: 1998/10/16 23:19:14 $

helpwin('dsp_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  dsp_con
%
%Double click on any function for more information
%
%  DSP Blockset.
%  Version 3.0   (R11) 10-Jul-1998
% 
%   What's new.
%    Readme     - New features, bug fixes, and changes in this version.
%                 To display the Readme file for Version 3.0, type
%                 "info dspblks" at the MATLAB command window.
% 
%   DSP Blockset Libraries v3.0
%    dspadpt2   - Adaptive filter structures
%    dsparch2   - Non-adaptive filter architectures
%    dspbdsp2   - Basic DSP signal operations
%    dspbuff2   - Data buffering blocks
%    dspddes2   - Digital and analog filter-design blocks
%    dspelem2   - Elementary functions library
%    dsplibv3   - Main DSP Blockset library for v3.0
%    dsplinalg  - Linear algebra library
%    dspmlti2   - Multirate filter blocks
%    dspmtrx2   - Matrix functions blocks
%    dspparest2 - Parameter estimation library 
%    dspsnks2   - DSP sinks library
%    dspspect2  - Spectral analysis library
%    dspsrcs2   - DSP sources library
%    dspstat2   - Statistics blocks
%    dspswit2   - Switches and counters
%    dspvect2   - Vector functions operations
%    dspxfrm2   - Vector signal transforms
% 
%   Filter Wizard
%    dspfwiz    - Filter realization wizard user interface
% 
%   DSP Blockset Libraries v2.2 and prior
%    dspadpt    - Adaptive filter structures
%    dsparch    - Non-adaptive filter architectures
%    dspbdsp    - Basic DSP signal operations
%    dspbuff    - Data buffering blocks
%    dspcmplx   - Complex math blocks
%    dspddes    - Digital and analog filter-design blocks
%    dspelmat   - Elementary (scalar) math blocks
%    dsplibv2   - Main DSP Blockset library for v2.2
%    dspmlti    - Multirate filter blocks
%    dspmtrx    - Matrix math operations
%    dspsnks    - DSP sinks library
%    dspspect   - Spectral analysis library
%    dspsrcs    - DSP sources library
%    dspstat    - Statistics operations
%    dspswit    - Switches
%    dspvect    - Vector math operations
%    dspxfrm    - Vector signal transforms
% 
%   -------------------------------------------
%
%  DSP Blockset S-Functions
% 
%   S-Functions v3.0
%    scumsum     - Cumulative sum
%    sdsp2norm   - Normalize input by the vector 2-norm
%    sdspacf     - Real autocorrelation
%    sdspbiquad  - Second-order section (biquad) filter implementation
%    sdspbsub    - Solve Ux=b by backward substitution
%    sdspbuffer  - Data buffering with over/underlap
%    sdspburg    - Burg method of AR parameter estimation
%    sdspchol    - Cholesky decomposition
%    sdspcontig  - Contiguous copy
%    sdspconv    - Buffered convolution
%    sdspcount   - Counter
%    sdspdct2    - Complex Discrete Cosine Transform (DCT)
%    sdspdf2t    - Multichannel IIR (Direct Form II Transposed) filter block
%    sdspdiag    - Full to diagonal, diagonal to full
%    sdspdiff    - Element-to-element difference along a vector
%    sdspdly     - Integer sample delay block
%    sdspdmult   - Multiply diagonal matrix by full matrix
%    sdspdsamp   - Downsample by an integer factor
%    sdspfft     - FFT on real or complex inputs
%    sdspfirdn   - Decimating FIR filter
%    sdspfsub    - Solve Lx=b by forward substitution
%    sdsphist    - Histogram
%    sdspifft    - Inverse FFT on complex inputs
%    sdspiirv    - Time-varying DF-II transposed filter
%    sdspinvdct  - Inverse DCT
%    sdspldl     - LDL factorization
%    sdsplevdurb - Levinson-Durbin solver for real correlation functions
%    sdsplu      - LU decomposition
%    sdspm1norm  - Matrix 1-norm
%    sdspmax     - Max
%    sdspmdn     - Median
%    sdspmean    - Mean
%    sdspmin     - Min
%    sdspmmult   - Matrix multiply
%    sdspmpclk   - Multiphase clock generator
%    sdspmtoep   - Toeplitz matrix constructor
%    sdspmtrnsp  - Matrix transpose
%    sdspmtwks   - Matrix to workspace
%    sdspnsamp   - N-sample enable
%    sdspperm    - Permute a vector or a matrix
%    sdspqueue   - Queue (FIFO register)
%    sdsprcond   - Reciprocal condition number estimation
%    sdsprepeat  - Repeat input samples N times
%    sdsprms     - RMS (root mean square)
%    sdspsine    - Frame-based sine wave
%    sdspsreg    - Shift register
%    sdspsrt     - Sort real and complex vectors
%    sdspstack   - Stack (LIFO register)
%    sdspstdvar  - Standard deviation and variance
%    sdsptri     - Lower/upper triangular matrices
%    sdsptsfw    - Triggered signal from workspace
%    sdspunbuff  - Unbuffer
%    sdspunwrap  - Unwrap a vector of radian phase angles
%    sdspupfir   - Interpolating FIR filter
%    sdspupfirdn - FIR rational sampling rate conversion filter
%    sdspupsamp  - Upsample
%    sdspvdf2t   - Time-varying multichannel IIR filtering
%    sdspvfdly   - Variable fractional delay
%    sdspvidly   - Variable integer delay
%    sdspwwv     - IRIG-H decoder for WWV time clock
%    sdspzpad    - Zero pad
%    sflip       - Vector flip
%    szerofi2    - Zero fill (upsample)
%    dsp_cplxhs11 - 1-inport/1-outport complex handshake code
%    dsp_cplxhs21 - 2-inport/1-outport complex handshake code
%    dspfft      - Used by FFT and DCT
%    dspifft     - Used by FFT and DCT
%    dspqsrt     - Used by sdspsrt and sdspmdn
%    dspqrdc     - Helper functions for QR decomposition
%    dspqrsl     - Helper functions for QR solver
%                
%   Utilities    
%    dsp_mex     - Rebuilds all MEX files for DSP Blockset
% 
%   S-Functions v2.2 and prior
%    sbufconv    - Vector convolution
%    sbuffer     - Overlapping buffer
%    sbufferc    - Vector buffering
%    sbufscop    - Vectorized graph scope
%    scmtxwks    - Complex matrix to workspace
%    scplxwks    - Complex to workspace
%    sdf2t       - Direct Form II (DF-II) transposed filter
%    sdf2tfrm    - Multichannel frame-based IIR DF-II transposed filter
%    sdspacfc    - Complex autocorrelation
%    sdspdct     - Complex Discrete Cosine Transform (DCT)
%    sdspdotp    - Dot product (multiply-accumulate)
%    sdsphst     - Histogram
%    sdspidct    - Complex Inverse DCT (IDCT)
%    sdspld      - Levinson-Durbin solver for real correlation functions
%    sdspldc     - Levinson-Durbin solver for complex correlation functions
%    sdspmnmx    - Min/Max
%    sdspr2c     - Convert real to complex
%    sdsprdct    - Real DCT
%    sdsprhst    - Running-histogram
%    sdspridct   - Real IDCT
%    sdspruns    - Running-statistics
%    sdspsort    - Sort real vectors
%    sdspstat    - Statistics functions
%    sdspupdn    - Upsample, apply a specified FIR filter, and downsample
%    sdspvdly    - Variable integer delay
%    selmath1    - Single input elementary math functions
%    selmath2    - Two input elementary math functions
%    sfft        - Fast Fourier Transform (FFT)
%    sfirdn      - Decimating FIR filter
%    slength     - Outputs the length of the input vector
%    smmultr     - Matrix multiplication
%    smtoepr     - Toeplitz matrix generator
%    smtrnsr     - Matrix transpose
%    smtrxwks    - Matrix to workspace
%    sndelay     - Discrete integer delay
%    snsample    - N-sample enable
%    spow        - u.^k and k.^u
%    srfft       - Real FFT
%    srfftc      - Real FFT
%    srifft      - Real Inverse FFT (conjugate symmetric input)
%    ssink       - Sinking unconnected outputs
%    sstatfcn    - Statistics functions
%    sunbuff     - Vector unbuffering
%    sunbuffc    - Complete vector unbuffering
%    supfir      - Interpolating FIR filter
%    svfdelay    - Variable fractional delay
%    szerofil    - Increase sample rate by inserting zeros into the signal
%    szeropad    - Zero pad
%    szoh        - Optimized zero-order hold for multirate blocks
%    fft         - FFT implementation used by FFT and DCT S-functions
% 
%   -------------------------------------------
%
%  DSP Blockset demonstrations and examples.
% 
%    dspadpcm   - Adaptive Delta Pulse Code Modulation (ADPCM)
%    dspafxf    - Audio flanging
%    dspafxr    - Audio reverberation
%    dspfsinecomp - Frame-based sine wave generation
%    dspintrp   - Interpolation via multirate filtering
%    dspintrpf  - Frame-based interpolation
%    dspmsmrf   - Multistage multirate filtering
%    dspmsmrff  - Frame-based multistage multirate filtering
%    dspqdemo   - Triggered sources and queues
%    dspsacomp  - Comparison of various spectral analysis methods
%    dspsdadc   - Sigma-Delta Analog-to-Digital conversion
%    dspsinecomp - Comparison of sine wave generation techniques
%    dspsrcnv   - Sample rate conversion
%    dspwdnois  - Wavelet denoising demonstration
%    dspwlet    - Wavelet function reconstruction
%    dspwpr1    - 1-level perfect reconstruction (PR) filter bank
%    dspwwv     - WWV digital time-code receiver
%    kalmnsce   - Kalman nonstationary channel estimation
%    lmsadeq    - LMS adaptive equalizer
%    lmsadlp    - LMS adaptive linear prediction
%    lmsadtde   - LMS adaptive time-delay estimation
%    lmsdemo    - LMS adaptive noise cancellation
%    olamodel   - Overlap-add method of spectral reconstruction
%    olapfilt   - Overlap-add and overlap-save frequency-domain filtering
%    rlsdemo    - RLS adaptive noise cancellation
%    ssbdemo    - Single Side Band (SSB) spectrum shifter
%    ssbdemof   - Frame-based SSB spectrum shifter
%    statsdem   - Statistics block library demonstration
%    welchdem   - Demonstration of short-time FFT
% 
%   

function Readme
%MATLAB Tour Partial Function Help:  dsp_con
%
%  README file for the DSP Blockset.
%  Version 3.0 8-Aug-1998
% 
%  The README FILE
%  This file contains a list of bug fixes, enhancements, limitations,
%  and new features in the DSP Blockset Version 3.0.
% 
%  INFRASTRUCTURE CHANGES
%  ----------------------
% 
%  - Multichannel frame-based processing
%    Blocks now support a frame-based processing mode which allows you
%    to more faithfully model real-time DSP applications.  Frame-based
%    processing also provides significant performance gains, both during
%    simulation and in the generated code (via RTW)
% 
%    All blocks which retain state information over time now provide
%    optional multichannel frame-based processing, including:
%    all filters, delays, running statistics, etc.
% 
%  - New intrinsic complex data types
%    Complex data is now an intrinsic data type, and blocks and
%    lines now automatically recognize when data is real or complex.
%    This greatly reduces the risk of unintentionally sending complex
%    data to a block which only accepts real inputs.
% 
%    All blocks now accept both real and complex data at their
%    input ports, including combinations of real and complex inputs.
% 
%    The internal format for complex data has fundamentally changed,
%    from a concatenation of the real followed by the imaginary part,
%    to an interleaving of the real and imaginary parts.  This leads
%    to increased efficiency when processing complex data and generating
%    code.
% 
%    The DSP Blockset Complex library is now obsolete, and all basic complex
%    blocks have moved to the Simulink library.  For example, complex math
%    may now be performed with the core Simulink math blocks.
% 
%  - Only source and sinks require sample time specifications
%    Enhancements to the Simulink S-Function API provides for automatic
%    propagation of sample time information, REMOVING the requirement
%    for sample times to be entered in block dialogs.
% 
%  - Dynamic dialogs
%    Masks now support "dynamic dialogs", where dialog controls may
%    now change dynamically in response to user entries, simplifying
%    block dialogs and reducing the chances for entry errors.
% 
% 
%  UPGRADING MODELS
%  ----------------
% 
%  - All old (v2.2 and prior) models are supported and will run
%    in this release while you transition to v3.0.  Note that there
%    is no automatic model upgrade facility.
% 
%  - A new utility (dsp_links) helps to locate and summarize usage
%    of DSP library blocks used in models.
% 
%  - You cannot directly mix the old complex data format with the
%    new intrinsic complex data type; conversion blocks are provided
%    in the Elementary Functions library which can translate between
%    the two complex formats while transitioning older models to v3.0.
% 
% 
%  NEW BLOCKS
%  ----------
% 
%  Sources
%  - Discrete Constant
%  - Triggered Signal From Workspace
%  - Vectorized Sine Wave
%  - From Wave File (PC only)
%  - From Wave Device (PC only)
% 
%  Sinks
%  - Time/Frequency Frame Scopes
%  - To Wave File (PC only)
%  - To Wave Device (PC only)
% 
%  Elementary Functions
%  - Convert Complex: DSP to Simulink
%  - Convert Complex: Simulink to DSP
%  - Contiguous Copy
%  - Inherit Complexity
%  - Variable Selector
% 
%  Matrix Functions
%  - Extract Triangular Matrix
%  - Extract Diagonal
%  - Create Diagonal Matrix
%  - Permute Matrix
%  - Matrix Scaling
%  - Matrix Sum (sum)
%  - Matrix Product (prod)
% 
%  Linear Algebra
%  - QR, LU, LDL, Cholesky factorization
%  - QR, LU, LDL, Cholesky, triangular solvers
%  - Reciprocal Condition estimation
% 
%  Buffers
%  - Rebuffer
%  - Stack
%  - Queue
% 
%  Switches and Counters
%  - Multiphase clock
%  - General up/down counter
%  - Event count comparator
%  - Edge detector
% 
%  Parametric Estimation
%  - Yule-Walker AR Estimator
%  - Burg AR Estimator, supporting both polynomial and
%      reflection coefficient outputs
%  - Covariance AR Estimator
%  - Modified Covariance AR Estimator
% 
%  Power Spectrum Estimation
%  - Short-Time FFT
%  - Magnitude FFT
%  - Yule-Walker Method
%  - Burg Method
%  - Covariance Method
%  - Modified Covariance Method
% 
%  Filter architectures
%  - Biquad filter block
%  - Time-varying direct-form II transpose filter
%  - Lattice filter block
% 
%  Adaptive Filters
%  - Enabled versions of LMS, RLS, and Kalman adaptive filters
% 
%  Multirate Filters
%  - Dyadic Analysis Filter Bank
%  - Dyadic Synthesis Filter Bank
% 
% 
%  BLOCK ENHANCEMENTS
%  ------------------
% 
%  - All blocks automatically accept real and complex data at their
%    input ports, including combinations of real/complex inputs.
% 
%  - All blocks which retain state information over time now provide
%    optional multichannel frame-based processing, including:
%      all filters       (all static, adaptive, and multirate blocks)
%      all delay blocks  (both static and variable blocks)
%      statistics blocks (min/max/etc)
% 
%  - All frame-based blocks now support multichannel operation, including:
%      FFT, Windows, Unbuffer, etc.
% 
%  - Brand new Frame Scope blocks for displaying the results of
%    frame-based simulations.  These blocks support multiple data
%    channels and are highly customizable..
% 
%  - Removed input port width requirement from Window block
% 
%  - Added optional value/index ports to min/max statistics blocks
% 
%  - Unbuffering now provides general output size/overlap parameters.
% 
%  - Filter Realization Wizard supports creation of filters which employ
%    blocks from the Fixed-Point Blockset in all filter realizations.

function dspadpt2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspadpt2 is a Simulink model

function dsparch2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dsparch2 is a Simulink model

function dspbdsp2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspbdsp2 is a Simulink model

function dspbuff2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspbuff2 is a Simulink model

function dspddes2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspddes2 is a Simulink model

function dspelem2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspelem2 is a Simulink model

function dsplibv3
%MATLAB Tour Partial Function Help:  dsp_con
%
%dsplibv3 is a Simulink model

function dsplinalg
%MATLAB Tour Partial Function Help:  dsp_con
%
%dsplinalg is a Simulink model

function dspmlti2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmlti2 is a Simulink model

function dspmtrx2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmtrx2 is a Simulink model

function dspparest2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspparest2 is a Simulink model

function dspsnks2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsnks2 is a Simulink model

function dspspect2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspspect2 is a Simulink model

function dspsrcs2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsrcs2 is a Simulink model

function dspstat2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspstat2 is a Simulink model

function dspswit2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspswit2 is a Simulink model

function dspvect2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspvect2 is a Simulink model

function dspxfrm2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspxfrm2 is a Simulink model

function dspfwiz
%MATLAB Tour Partial Function Help:  dsp_con
%
%  DSPFWIZ Filter Wizard user interface
%          Automatically generates filter architecture models in SIMULINK.

function dspadpt
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspadpt is a Simulink model

function dsparch
%MATLAB Tour Partial Function Help:  dsp_con
%
%dsparch is a Simulink model

function dspbdsp
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspbdsp is a Simulink model

function dspbuff
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspbuff is a Simulink model

function dspcmplx
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspcmplx is a Simulink model

function dspddes
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspddes is a Simulink model

function dspelmat
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspelmat is a Simulink model

function dsplibv2
%MATLAB Tour Partial Function Help:  dsp_con
%
%dsplibv2 is a Simulink model

function dspmlti
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmlti is a Simulink model

function dspmtrx
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmtrx is a Simulink model

function dspsnks
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsnks is a Simulink model

function dspspect
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspspect is a Simulink model

function dspsrcs
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsrcs is a Simulink model

function dspstat
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspstat is a Simulink model

function dspswit
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspswit is a Simulink model

function dspvect
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspvect is a Simulink model

function dspxfrm
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspxfrm is a Simulink model

function dsp_mex
%MATLAB Tour Partial Function Help:  dsp_con
%
%  DSP_MEX Utility function for DSP Blockset.
%    DSP_MEX rebuilds all MEX files for DSP Blockset.
%    DSP_MEX -v shows the lines which will execute, but will not rebuild files.

function sbufscop
%MATLAB Tour Partial Function Help:  dsp_con
%
% sbufscop SIMULINK vector scope S-Function.
% 	sbufscop is a SIMULINK S-Function that plots the input vector in
% 	a Handle Graphics(tm) figure window.  The figure is named and tagged
% 	with the full name of the scope block.
% 
% 	The input vector can be interpreted as a vector of sampled data or 
% 	a vector of frequencies.  The calling sequence is:
% 	    sbufscop(T,X,U,FLAG,SCALING,DOMAIN,FIGPOS,YLABELSTR,RADS)
% 	The first four input arguments T, X, U, and FLAG are the four 
% 	required SIMULINK input arguments.  The other parameters are:
% 	    SCALING determines the X-axis limits.
% 	    DOMAIN specifies whether the input is time or frequency data.
% 	    FIGPOS is a position rectangle in pixels which specifies
% 	     the position of the scope's figure window.
% 	    YLABELSTR is an optional argument that specifies the Y-label.  
% 	     Default is 'Magnitude'.
% 	    RADS is an optional argument that is used to specify the units 
% 	     for the X-axis.  If 1 the X-axis units are in radians or if 0 
% 	     (the default if not present) the X-axis units are in hertz (Hz).

function fft
%MATLAB Tour Partial Function Help:  dsp_con
%
% FFT Discrete Fourier transform.
%    FFT(X) is the discrete Fourier transform (DFT) of vector X.  If the
%    length of X is a power of two, a fast radix-2 fast-Fourier
%    transform algorithm is used.  If the length of X is not a
%    power of two, a slower non-power-of-two algorithm is employed.
%    For matrices, the FFT operation is applied to each column.
%    For N-D arrays, the FFT operation operates on the first
%    non-singleton dimension.
% 
%    FFT(X,N) is the N-point FFT, padded with zeros if X has less
%    than N points and truncated if it has more.
% 
%    FFT(X,[],DIM) or FFT(X,N,DIM) applies the FFT operation across the
%    dimension DIM.
%    
%    For length N input vector x, the DFT is a length N vector X,
%    with elements
%                     N
%       X(k) =       sum  x(n)*exp(-j*2*pi*(k-1)*(n-1)/N), 1 <= k <= N.
%                    n=1
%    The inverse DFT (computed by IFFT) is given by
%                     N
%       x(n) = (1/N) sum  X(k)*exp( j*2*pi*(k-1)*(n-1)/N), 1 <= n <= N.
%                    k=1
% 
%    The relationship between the DFT and the Fourier coefficients a and b in
%                N/2
%    x(n) = a0 + sum a(k)*cos(2*pi*k*t(n)/(N*dt))+b(k)*sin(2*pi*k*t(n)/(N*dt))
%                k=1
%    is
%       a0 = X(1)/N, a(k) = 2*real(X(k+1))/N, b(k) = -2*imag(X(k+1))/N,
%    where x is a length N discrete signal sampled at times t with spacing dt.
% 
%    

function dspadpcm
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspadpcm is a Simulink model

function dspafxf
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspafxf is a Simulink model

function dspafxr
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspafxr is a Simulink model

function dspfsinecomp
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspfsinecomp is a Simulink model

function dspintrp
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspintrp is a Simulink model

function dspintrpf
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspintrpf is a Simulink model

function dspmsmrf
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmsmrf is a Simulink model

function dspmsmrff
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspmsmrff is a Simulink model

function dspqdemo
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspqdemo is a Simulink model

function dspsacomp
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsacomp is a Simulink model

function dspsdadc
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsdadc is a Simulink model

function dspsinecomp
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsinecomp is a Simulink model

function dspsrcnv
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspsrcnv is a Simulink model

function dspwdnois
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspwdnois is a Simulink model

function dspwlet
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspwlet is a Simulink model

function dspwpr1
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspwpr1 is a Simulink model

function dspwwv
%MATLAB Tour Partial Function Help:  dsp_con
%
%dspwwv is a Simulink model

function kalmnsce
%MATLAB Tour Partial Function Help:  dsp_con
%
%kalmnsce is a Simulink model

function lmsadeq
%MATLAB Tour Partial Function Help:  dsp_con
%
%lmsadeq is a Simulink model

function lmsadlp
%MATLAB Tour Partial Function Help:  dsp_con
%
%lmsadlp is a Simulink model

function lmsadtde
%MATLAB Tour Partial Function Help:  dsp_con
%
%lmsadtde is a Simulink model

function lmsdemo
%MATLAB Tour Partial Function Help:  dsp_con
%
%lmsdemo is a Simulink model

function olamodel
%MATLAB Tour Partial Function Help:  dsp_con
%
%olamodel is a Simulink model

function olapfilt
%MATLAB Tour Partial Function Help:  dsp_con
%
%olapfilt is a Simulink model

function rlsdemo
%MATLAB Tour Partial Function Help:  dsp_con
%
%rlsdemo is a Simulink model

function ssbdemo
%MATLAB Tour Partial Function Help:  dsp_con
%
%ssbdemo is a Simulink model

function ssbdemof
%MATLAB Tour Partial Function Help:  dsp_con
%
%ssbdemof is a Simulink model

function statsdem
%MATLAB Tour Partial Function Help:  dsp_con
%
%statsdem is a Simulink model

